==> prestashop_1.4.0.14.zip: prestashop/modules/blockrss/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{blockrss}prestashop>blockrss_2516c13a12d3dbaf4efa88d9fce2e7da'] = 'RSS-Feed-Block';
$_MODULE['<{blockrss}prestashop>blockrss_be3b59f9eca89af2df840316a25e4b1d'] = 'Fügt einen Block hinzu, der ein RSS-Feed anzeigt';
$_MODULE['<{blockrss}prestashop>blockrss_9680162225162baf2a085dfdc2814deb'] = 'RSS-Feed';
$_MODULE['<{blockrss}prestashop>blockrss_6706b6d8ba45cc4f0eda0506ba1dc3c8'] = 'Ungültige Feed-URL';
$_MODULE['<{blockrss}prestashop>blockrss_36ed65ce17306e812fd68d9f634c0c57'] = 'Ungültiger Titel';
$_MODULE['<{blockrss}prestashop>blockrss_1b3d34e25aef32a3c8daddfff856577f'] = 'Ungültige Anzahl von RSS-Feeds';
$_MODULE['<{blockrss}prestashop>blockrss_3485b08295c5e96444091cc8b09cafbf'] = 'Sie haben eine Feed-URL auf Ihrer eigenen Website ausgewählt, dies ist wahrscheinlich ein Fehler! Wählen Sie eine andere URL (zB http://news.google.com/?output=rss), bis Sie wissen, was Sie wünschen';
$_MODULE['<{blockrss}prestashop>blockrss_c888438d14855d7d96a2724ee9c306bd'] = 'Einstellungen aktualisiert';
$_MODULE['<{blockrss}prestashop>blockrss_f4f70727dc34561dfde1a3c529b6205c'] = 'Einstellungen';
$_MODULE['<{blockrss}prestashop>blockrss_b22c8f9ad7db023c548c3b8e846cb169'] = 'Block Titel';
$_MODULE['<{blockrss}prestashop>blockrss_2343a40bdffd8c7a6317b6d98c2b1042'] = 'Erstellen Sie einen Titel für den Block (Standard: \'RSS-Feed\')';
$_MODULE['<{blockrss}prestashop>blockrss_402d00ca8e4f0fff26fc24ee9ab8e82b'] = 'Fügen Sie einen Feed-URL hinzu';
$_MODULE['<{blockrss}prestashop>blockrss_eb26a56cc4c9ae20bc55c887773bddfd'] = 'Fügen Sie die URL des Feeds hinzu, die Sie verwenden möchten';
$_MODULE['<{blockrss}prestashop>blockrss_ff9aa540e20285875ac8b190a3cb7ccf'] = 'Anzahl der angezeigten Threads';
$_MODULE['<{blockrss}prestashop>blockrss_595f3fab84b35a00db28d3eb3b3d92fa'] = 'Anzahl der im Block angezeigten Threads (Standardwert: 5)';
$_MODULE['<{blockrss}prestashop>blockrss_c9cc8cce247e49bae79f15173ce97354'] = 'Speichern';
$_MODULE['<{blockrss}prestashop>blockrss_10fd25dcd3353c0ba3731d4a23657f2e'] = 'Kein RSS Feed hinzugefügt';

==> prestashop_1.4.3.0.zip: prestashop/modules/blockrss/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{blockrss}prestashop>blockrss_10fd25dcd3353c0ba3731d4a23657f2e'] = 'Kein RSS Feed hinzugefügt';
$_MODULE['<{blockrss}prestashop>blockrss_2516c13a12d3dbaf4efa88d9fce2e7da'] = 'RSS-Feed-Block';
$_MODULE['<{blockrss}prestashop>blockrss_04396664ce529aa4204b0f7ad753fad1'] = 'Fügt einen Block hinzu, der ein RSS-Feed anzeigt';
$_MODULE['<{blockrss}prestashop>blockrss_9680162225162baf2a085dfdc2814deb'] = 'RSS-Feed';
$_MODULE['<{blockrss}prestashop>blockrss_6706b6d8ba45cc4f0eda0506ba1dc3c8'] = 'Ungültige Feed-URL';
$_MODULE['<{blockrss}prestashop>blockrss_36ed65ce17306e812fd68d9f634c0c57'] = 'Ungültiger Titel';
$_MODULE['<{blockrss}prestashop>blockrss_1b3d34e25aef32a3c8daddfff856577f'] = 'Ungültige Anzahl von RSS-Feeds';
$_MODULE['<{blockrss}prestashop>blockrss_606a95aefd4296583b685aa039f01681'] = 'Sie haben eine Feed-URL auf Ihrer eigenen Website ausgewählt, dies ist wahrscheinlich ein Fehler! Wählen Sie eine andere URL (zB http://news.google.com/?output=rss), bis Sie wissen, was Sie wünschen';
$_MODULE['<{blockrss}prestashop>blockrss_c888438d14855d7d96a2724ee9c306bd'] = 'Einstellungen aktualisiert';
$_MODULE['<{blockrss}prestashop>blockrss_f4f70727dc34561dfde1a3c529b6205c'] = 'Einstellungen';
$_MODULE['<{blockrss}prestashop>blockrss_b22c8f9ad7db023c548c3b8e846cb169'] = 'Block Titel';
$_MODULE['<{blockrss}prestashop>blockrss_2343a40bdffd8c7a6317b6d98c2b1042'] = 'Erstellen Sie einen Titel für den Block (Standard: \'RSS-Feed\')';
$_MODULE['<{blockrss}prestashop>blockrss_402d00ca8e4f0fff26fc24ee9ab8e82b'] = 'Fügen Sie einen Feed-URL hinzu';
$_MODULE['<{blockrss}prestashop>blockrss_eb26a56cc4c9ae20bc55c887773bddfd'] = 'Fügen Sie die URL des Feeds hinzu, die Sie verwenden möchten';
$_MODULE['<{blockrss}prestashop>blockrss_ff9aa540e20285875ac8b190a3cb7ccf'] = 'Anzahl der angezeigten Threads';
$_MODULE['<{blockrss}prestashop>blockrss_f33725e23a017705ad35897e849a4db4'] = 'Anzahl der im Block angezeigten Threads (Standardwert: 5)';
$_MODULE['<{blockrss}prestashop>blockrss_c9cc8cce247e49bae79f15173ce97354'] = 'Speichern';

?>
